@@ -1,5 +1,5 @@
 package Net::Stripe::Invoice;
-$Net::Stripe::Invoice::VERSION = '0.35';
+$Net::Stripe::Invoice::VERSION = '0.36';
 use Moose;
 use Kavorka;
 extends 'Net::Stripe::Resource';
@@ -61,151 +61,7 @@ Net::Stripe::Invoice - represent an Invoice object from Stripe
 
 =head1 VERSION
 
-version 0.35
-
-=head1 ATTRIBUTES
-
-=head2 amount_due
-
-Reader: amount_due
-
-Type: Maybe[Int]
-
-This attribute is required.
-
-=head2 attempt_count
-
-Reader: attempt_count
-
-Type: Maybe[Int]
-
-This attribute is required.
-
-=head2 attempted
-
-Reader: attempted
-
-Type: Maybe[Bool|Object]
-
-This attribute is required.
-
-=head2 charge
-
-Reader: charge
-
-Type: Maybe[Str]
-
-=head2 closed
-
-Reader: closed
-
-Type: Maybe[Bool|Object]
-
-This attribute is required.
-
-=head2 created
-
-Reader: created
-
-Type: Maybe[Int]
-
-=head2 customer
-
-Reader: customer
-
-Type: Maybe[Str]
-
-This attribute is required.
-
-=head2 date
-
-Reader: date
-
-Type: Maybe[Str]
-
-This attribute is required.
-
-=head2 description
-
-Reader: description
-
-Writer: description
-
-Type: Maybe[Str]
-
-=head2 ending_balance
-
-Reader: ending_balance
-
-Type: Maybe[Int]
-
-=head2 id
-
-Reader: id
-
-Type: Maybe[Str]
-
-=head2 lines
-
-Reader: lines
-
-Type: Net::Stripe::List
-
-This attribute is required.
-
-=head2 metadata
-
-Reader: metadata
-
-Writer: metadata
-
-Type: HashRef
-
-=head2 next_payment_attempt
-
-Reader: next_payment_attempt
-
-Type: Maybe[Int]
-
-=head2 paid
-
-Reader: paid
-
-Type: Maybe[Bool|Object]
-
-This attribute is required.
-
-=head2 period_end
-
-Reader: period_end
-
-Type: Maybe[Int]
-
-=head2 period_start
-
-Reader: period_start
-
-Type: Maybe[Int]
-
-=head2 starting_balance
-
-Reader: starting_balance
-
-Type: Maybe[Int]
-
-=head2 subtotal
-
-Reader: subtotal
-
-Type: Maybe[Int]
-
-=head2 total
-
-Reader: total
-
-Type: Maybe[Int]
-
-This attribute is required.
+version 0.36
 
 =head1 AUTHORS
 
